import 'package:habo/model/category.dart';

abstract class CategoryRepository {
  Future<List<Category>> getAllCategories();
  Future<int> createCategory(Category category);
  Future<void> updateCategory(Category category);
  Future<void> deleteCategory(int id);
  Future<void> updateHabitCategories(int habitId, List<Category> categories);
  Future<List<Category>> getCategoriesForHabit(int habitId);
  Future<void> deleteAllCategories();
}
